@@ -80,6 +80,10 @@ func (ptc *pluginTemplateCmd) runPluginCmd(cmd *cobra.Command, args []string) er
 		log.WithFields(log.Fields{
 			"prefix": "pluginTemplateCmd.runPluginCmd",
 		}).Debug(fmt.Sprintf("Plugin command '%s' exited with error: %s", plugin.Shortname, err))
+
+		// We can't return err because the plugin will have already printed the error message at
+		// this point, and we can't return nil because the host will exit with code 0.
+		os.Exit(1)
 	}
 
 	return nil
